@@ -4,7 +4,7 @@ Text::CSV::Track - module to work with .csv file that stores some value(s) per i
 
 =head1 VERSION
 
-This documentation refers to version 0.6. 
+This documentation refers to version 0.7. 
 
 =head1 SYNOPSIS
 
@@ -207,10 +207,14 @@ and closes csv filehandle.
 	- then rewrite max/min to use it this way
 	- constraints for columns
 	- shell executable to copy, dump csv file or extract data from it
+	- allow having extended csv with header names in every file key=value;key2=value2
+	- atomic writes
+	- allow extended csv lines, lines that look like:
+	    key=value1,key5=value2,key2=value3
 
 =head1 SEE ALSO
 
-L<Text::CSV::Track::Max>, L<Text::CSV::Track::Min>, SVN repository - L<http://svn.cle.sk/svn/pub/cpan/Text-CSV-Track/>
+L<Text::CSV::Track::Max>, L<Text::CSV::Track::Min>, Module Trac - L<http://trac.cle.sk/Text-CSV-Track/>
 
 =head1 AUTHOR
 
@@ -222,7 +226,7 @@ Jozef Kutej <jozef.kutej@hp.com>
 
 package Text::CSV::Track;
 
-our $VERSION = '0.6';
+our $VERSION = '0.7';
 use 5.006;
 
 use strict;
@@ -747,3 +751,17 @@ sub DESTROY {
 }
 
 1;
+
+=head1 AUTHOR
+
+Jozef Kutej - E<lt>jozef@kutej.netE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2006 by Jozef Kutej
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.4 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
